<?php
/* --------------------------------------------------------------
   dependent.inc.php 2022-04-27
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2022 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------*/

/** @var DatabaseModel $this */
/** @var bool $t_success */

$query = <<<SQL
INSERT INTO `properties_values_description`(`properties_values_id`, `language_id`, `values_name`, `description`)
SELECT
    `pv`.`properties_values_id`,
    `l2`.`languages_id`,
    'unnamed value' AS `values_name`,
    '' AS `description`
FROM properties_values AS pv
         LEFT JOIN `properties_values_description` pvd ON `pv`.`properties_values_id` = `pvd`.`properties_values_id`
         LEFT JOIN `languages` l ON `pvd`.`language_id` = `l`.`languages_id`
         LEFT JOIN `languages` l2 ON 1
WHERE `l`.`code` IS NULL
GROUP BY `pv`.`properties_values_id`, `l2`.`languages_id`, `pv`.`properties_id`
ORDER BY `pv`.`properties_id`;
SQL;

$t_success &= is_numeric($this->query($query));

$themeJsonFiles = glob(DIR_FS_CATALOG . 'themes/*/contentzones/*.json');
if (is_array($themeJsonFiles)) {
    foreach ($themeJsonFiles as $jsonFile) {
        $fileContent = file_get_contents($jsonFile);
        
        if (strpos($fileContent, 'placehold.it') === false) {
            continue;
        }
        
        $search = [
            '"\/\/placehold.it\/400x200?text=100%"',
            '"\/\/placehold.it\/400x200?text=50%x50%"',
            '"\/\/placehold.it\/400x200?text=33%x66%"',
            '"\/\/placehold.it\/400x200?text=66%x33%"',
            '"\/\/placehold.it\/400x200?text=25%x75%"',
            '"\/\/placehold.it\/400x200?text=75%x25%"',
            '"\/\/placehold.it\/400x200?text=33%x33%x33%"',
            '"\/\/placehold.it\/400x200?text=25%x25%x25%x25%"',
        ];
        
        $replace = [
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/100.png"',
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/50-50.png"',
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/33-66.png"',
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/66-33.png"',
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/25-75.png"',
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/75-25.png"',
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/33-33-33.png"',
            '"..\/..\/..\/..\/GXModules\/Gambio\/ContentZones\/Images\/25-25-25-25.png"',
        ];
        
        $fileContent = str_replace($search, $replace, $fileContent);
        
        $deleteSuccess = unlink($jsonFile);
        
        if ($deleteSuccess) {
            file_put_contents($jsonFile, $fileContent);
            @chmod($jsonFile, 0777);
        }
    }
}

/**
 * Restore the `options_id` column in the `products_properties_combis_values` database table,
 * which might have been destroyed when editing the product variants.
 */
if ($this->columnExists('products_properties_combis_values', 'options_id')) {
    $query = 'UPDATE `products_properties_combis_values` `ppcv` '
             . 'JOIN `properties_values` `pv` ON  `ppcv`.`properties_values_id` = `pv`.`properties_values_id` '
             . 'SET `ppcv`.`options_id` = `pv`.`properties_id`;';
    
    $t_success &= is_numeric($this->query($query));
}

// Adds the SHOW_SUBCATEGORIES_PARENT configuration if it's missing
$result = $this->query("SELECT * FROM `gx_configurations` WHERE `key` = 'gm_configuration/SHOW_SUBCATEGORIES_PARENT';");
if (!$result) {
    $insertQuery = "INSERT INTO `gx_configurations` (`key`, `value`, `default`, `type`, `sort_order`) VALUES ('gm_configuration/SHOW_SUBCATEGORIES_PARENT',  'false', 'false', 'switcher', NULL);";
    $t_success &= $this->query($insertQuery, true);
}